window.Gleam.initSearch([{"doc":"clockwork","title":"clockwork","content":"# clockwork\n\n[![Package Version](https://img.shields.io/hexpm/v/clockwork)](https://hex.pm/packages/clockwork)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/clockwork/)\n\n```sh\ngleam add clockwork\n```\n\n```gleam\nimport clockwork\nimport clockwork/schedule\nimport gleam/erlang/process\nimport gleam/io\n\npub fn main() {\n\n  // Here we create a cron schedule that triggers\n  // every 15 minutes on the 1st and 15th of the month,\n  // from May to October, every two week-days from Tuesday to Saturday.\n  let assert Ok(cron) = &quot;*/15 0 1,15 5-10 2-6/2&quot; |&gt; clockwork.from_string\n\n  /// Here we create a cron using functions instead.\n  let cron = clockwork.default()\n    |&gt; clockwork.with_minute(clockwork.every(15))\n    |&gt; clockwork.with_hour(clockwork.exactly(at: 0))\n    |&gt; clockwork.with_day(clockwork.list([clockwork.exactly(1), clockwork.exactly(15)]))\n    |&gt; clockwork.with_month(clockwork.ranging(from: 5, to: 10))\n    |&gt; clockwork.with_weekday(clockwork.ranging_every(2, from: 2, to: 6))\n\n  let now = ...\n\n  // Here we calculate the next occurrence\n  // of the cron schedule after the given timestamp.\n  clockwork.next_occurrence(given: cron, from: now)\n\n  // Here we schedule a function to be executed given the cron schedule.\n  schedule.configure_logger()\n  schedule.start(&quot;my_schedule&quot;, cron, fn() { io.println(&quot;Hello, world!&quot;) })\n  process.sleep_forever()\n\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/clockwork&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"clockwork","title":"Cron","content":"pub type Cron {\n  Cron(\n    minute: CronField,\n    hour: CronField,\n    day: CronField,\n    month: CronField,\n    weekday: CronField,\n  )\n}\n\nCron(\n  minute: CronField,\n  hour: CronField,\n  day: CronField,\n  month: CronField,\n  weekday: CronField,\n)\n\n\nSynonyms:\nclockwork.Cron\nclockwork Cron","url":"clockwork.html#Cron"},{"doc":"clockwork","title":"CronField","content":"pub opaque type CronField\n\n\nSynonyms:\nclockwork.CronField\nclockwork CronField","url":"clockwork.html#CronField"},{"doc":"clockwork","title":"default","content":"pub fn default() -&gt; Cron\n Default cron struct with all fields set to wildcard.\nSynonyms:\nclockwork.default\nclockwork default","url":"clockwork.html#default"},{"doc":"clockwork","title":"every","content":"pub fn every(step: Int) -&gt; CronField\n\nSynonyms:\nclockwork.every\nclockwork every","url":"clockwork.html#every"},{"doc":"clockwork","title":"every_time","content":"pub fn every_time() -&gt; CronField\n Wildcard field for a cron struct.\nSynonyms:\nclockwork.every_time\nclockwork every_time","url":"clockwork.html#every_time"},{"doc":"clockwork","title":"exactly","content":"pub fn exactly(at v: Int) -&gt; CronField\n Value field for a cron struct.\nSynonyms:\nclockwork.exactly\nclockwork exactly","url":"clockwork.html#exactly"},{"doc":"clockwork","title":"from_string","content":"pub fn from_string(cron: String) -&gt; Result(Cron, Nil)\n Parse a cron string into a Cron struct.\nSynonyms:\nclockwork.from_string\nclockwork from_string","url":"clockwork.html#from_string"},{"doc":"clockwork","title":"list","content":"pub fn list(fields: List(CronField)) -&gt; CronField\n List field for a cron struct.\nSynonyms:\nclockwork.list\nclockwork list","url":"clockwork.html#list"},{"doc":"clockwork","title":"next_occurrence","content":"pub fn next_occurrence(\n  given cron: Cron,\n  from from: Timestamp,\n) -&gt; Timestamp\n Returns the next occurrence of a cron job after the given timestamp.\nSynonyms:\nclockwork.next_occurrence\nclockwork next_occurrence","url":"clockwork.html#next_occurrence"},{"doc":"clockwork","title":"ranging","content":"pub fn ranging(from start: Int, to end: Int) -&gt; CronField\n Range field for a cron struct.\nSynonyms:\nclockwork.ranging\nclockwork ranging","url":"clockwork.html#ranging"},{"doc":"clockwork","title":"ranging_every","content":"pub fn ranging_every(\n  step: Int,\n  from start: Int,\n  to end: Int,\n) -&gt; CronField\n\nSynonyms:\nclockwork.ranging_every\nclockwork ranging_every","url":"clockwork.html#ranging_every"},{"doc":"clockwork","title":"stepping","content":"pub fn stepping(every step: Int, from from: Int) -&gt; CronField\n\nSynonyms:\nclockwork.stepping\nclockwork stepping","url":"clockwork.html#stepping"},{"doc":"clockwork","title":"to_string","content":"pub fn to_string(cron: Cron) -&gt; String\n Convert a Cron struct into a cron string.\nSynonyms:\nclockwork.to_string\nclockwork to_string","url":"clockwork.html#to_string"},{"doc":"clockwork","title":"with_day","content":"pub fn with_day(cron: Cron, day: CronField) -&gt; Cron\n Set the day field of a cron struct.\nSynonyms:\nclockwork.with_day\nclockwork with_day","url":"clockwork.html#with_day"},{"doc":"clockwork","title":"with_hour","content":"pub fn with_hour(cron: Cron, hour: CronField) -&gt; Cron\n Set the hour field of a cron struct.\nSynonyms:\nclockwork.with_hour\nclockwork with_hour","url":"clockwork.html#with_hour"},{"doc":"clockwork","title":"with_minute","content":"pub fn with_minute(cron: Cron, minute: CronField) -&gt; Cron\n Set the minute field of a cron struct.\nSynonyms:\nclockwork.with_minute\nclockwork with_minute","url":"clockwork.html#with_minute"},{"doc":"clockwork","title":"with_month","content":"pub fn with_month(cron: Cron, month: CronField) -&gt; Cron\n Set the month field of a cron struct.\nSynonyms:\nclockwork.with_month\nclockwork with_month","url":"clockwork.html#with_month"},{"doc":"clockwork","title":"with_weekday","content":"pub fn with_weekday(cron: Cron, weekday: CronField) -&gt; Cron\n Set the weekday field of a cron struct.\n Weekdays are 0-indexed, starting from Sunday.\nSynonyms:\nclockwork.with_weekday\nclockwork with_weekday","url":"clockwork.html#with_weekday"},{"doc":"clockwork","title":"clockwork","content":"","url":"clockwork.html"},{"doc":"clockwork/schedule","title":"Message","content":"pub type Message {\n  Run\n  Stop\n}\n\nRun\n\n\nStop\n\n\nSynonyms:\nclockwork/schedule.Message\nclockwork/schedule Message","url":"clockwork/schedule.html#Message"},{"doc":"clockwork/schedule","title":"Schedule","content":"pub type Schedule {\n  Schedule(subject: process.Subject(Message))\n}\n\nSchedule(subject: process.Subject(Message))\n\n\nSynonyms:\nclockwork/schedule.Schedule\nclockwork/schedule Schedule","url":"clockwork/schedule.html#Schedule"},{"doc":"clockwork/schedule","title":"configure_logger","content":"pub fn configure_logger() -&gt; Nil\n\nSynonyms:\nclockwork/schedule.configure_logger\nclockwork/schedule configure_logger","url":"clockwork/schedule.html#configure_logger"},{"doc":"clockwork/schedule","title":"start","content":"pub fn start(\n  name: String,\n  with cron: Cron,\n  do job: fn() -&gt; Nil,\n) -&gt; Result(Schedule, StartError)\n\nSynonyms:\nclockwork/schedule.start\nclockwork/schedule start","url":"clockwork/schedule.html#start"},{"doc":"clockwork/schedule","title":"stop","content":"pub fn stop(schedule: Schedule) -&gt; Nil\n\nSynonyms:\nclockwork/schedule.stop\nclockwork/schedule stop","url":"clockwork/schedule.html#stop"},{"doc":"clockwork/schedule","title":"clockwork/schedule","content":"","url":"clockwork/schedule.html"}]);